#loginsignupdialog {
    position: absolute;
    background-color: #ffffff;
    left: 0px;
    top: 0px;
    width: calc(100% - 0px);
    height: calc(100% - 0px);
    font-size: 13px;
    margin: 0px;
    padding: 0px;
    z-index: 201;
}

#loginsignupdialog button {
    font-size: 16px;
}

#loginsignupdialog img {
    width: 130px;
    position: fixed;
    top: 50px;
    left: 50%;
    transform: translateX(-50%);
}

#logindiv {
    position: absolute;
    left: 50%;
    top: 50%;
    font-size: 18px;
    line-height: 33px;
    text-align: center;
    transform: translate(-50%, -50%);
    color: black;
}

#logindiv table tbody tr td:first-child {
    text-align: right;
}

#forgotpassworddiv {
    position: absolute;
    left: 50%;
    top: 50%;
    font-size: 18px;
    line-height: 33px;
    text-align: center;
    transform: translate(-50%, -50%);
    color: black;
}

#signupdiv {
    position: absolute;
    left: calc(50% - 150px);
    top: calc(50% - 125px);
    font-size: 18px;
    line-height: 33px;
    text-align: center;
    color: black;
}

#signupdiv table tbody tr td:first-child {
    text-align: right;
}

#forgotpasswordgetquestiondiv {
    text-align: center;
}

#changepassworddiv {
    display: none;
    position: absolute;
    padding: 10px;
    background-color: white;
    border: 1px solid black;
}

#admindiv {
    position: relative;
    top: 100px;
    height: calc(100% - 100px);
}

.adminsection-title {
    text-decoration: underline;
}

.adminsection-div {
    /*border: 1px solid black;*/
    padding: 10px;
}

.adminsection-div table {
    margin: 20px;
}

#accountdiv {
    position: absolute;
    right: 96px;
    top: 4px;
}

#accountdiv span {
    font-size: 12px;
}

#logdiv {
    display: inline-block;
}

#logdiv img {
    height: 18px;
    cursor: pointer;
    vertical-align: middle;
}

body * {
    font-family: 'roboto-light';
}

@font-face {
    font-family: 'roboto-medium';
    src: url('/result/fonts/roboto-medium-webfont.woff') format('woff'),
         url('/result/fonts/roboto-medium-webfont.woff2') format('woff2');
}

@font-face {
    font-family: 'roboto-light';
    src: url('/result/fonts/roboto-light-webfont.woff') format('woff'),
         url('/result/fonts/roboto-light-webfont.woff2') format('woff2');
}

@font-face {
    font-family: 'roboto-bold';
    src: url('/result/fonts/roboto-bold-webfont.woff') format('woff'),
         url('/result/fonts/roboto-bold-webfont.woff2') format('woff2');
}

@font-face {
    font-family: 'sourcesanspro-bold';
    src: url('/result/fonts/sourcesanspro-bold-webfont.woff') format('woff'),
         url('/result/fonts/sourcesanspro-bold-webfont.woff2') format('woff2');
}

#yesnodialog {
    z-index: 202;
}

